==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/lib/l10n/mk.js <==
OC.L10N.register(
    "lib",
    {
    "Help" : "Помош",
    "Personal" : "Лично",
    "Users" : "Корисници",
    "Admin" : "Админ",
    "No app name specified" : "Не е специфицирано име на апликацијата",
    "Unknown filetype" : "Непознат тип на датотека",
    "Invalid image" : "Невалидна фотографија",
    "today" : "денеска",
    "yesterday" : "вчера",
    "last month" : "минатиот месец",
    "last year" : "минатата година",
    "seconds ago" : "пред секунди",
    "web services under your control" : "веб сервиси под Ваша контрола",
    "Application is not enabled" : "Апликацијата не е овозможена",
    "Authentication error" : "Грешка во автентикација",
    "Token expired. Please reload page." : "Жетонот е истечен. Ве молам превчитајте ја страницата.",
    "Unknown user" : "Непознат корисник",
    "%s enter the database username." : "%s внеси го корисничкото име за базата.",
    "%s enter the database name." : "%s внеси го името на базата.",
    "%s you may not use dots in the database name" : "%s не можеш да користиш точки во името на базата",
    "Oracle username and/or password not valid" : "Oracle корисничкото име и/или лозинката не се валидни",
    "DB Error: \"%s\"" : "DB грешка: \"%s\"",
    "Offending command was: \"%s\"" : "Навредувшката команда беше: \"%s\"",
    "PostgreSQL username and/or password not valid" : "PostgreSQL корисничкото име и/или лозинка не се валидни",
    "Set an admin username." : "Постави администраторско корисничко име",
    "Set an admin password." : "Постави администраторска лозинка.",
    "%s shared »%s« with you" : "%s споделено »%s« со вас",
    "Could not find category \"%s\"" : "Не можам да најдам категорија „%s“",
    "Apps" : "Аппликации",
    "A valid username must be provided" : "Мора да се обезбеди валидно корисничко име ",
    "A valid password must be provided" : "Мора да се обезбеди валидна лозинка",
    "The username is already being used" : "Корисничкото име е веќе во употреба"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> owncloud-9.0.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/lib/l10n/mk.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Не можам да впишувам во \"config\" директориумот!",
    "Help" : "Помош",
    "Personal" : "Лично",
    "Users" : "Корисници",
    "Admin" : "Админ",
    "No app name specified" : "Не е специфицирано име на апликацијата",
    "Unknown filetype" : "Непознат тип на датотека",
    "Invalid image" : "Невалидна фотографија",
    "today" : "денеска",
    "yesterday" : "вчера",
    "last month" : "минатиот месец",
    "last year" : "минатата година",
    "seconds ago" : "пред секунди",
    "web services under your control" : "веб сервиси под Ваша контрола",
    "Application is not enabled" : "Апликацијата не е овозможена",
    "Authentication error" : "Грешка во автентикација",
    "Token expired. Please reload page." : "Жетонот е истечен. Ве молам превчитајте ја страницата.",
    "Unknown user" : "Непознат корисник",
    "%s enter the database username." : "%s внеси го корисничкото име за базата.",
    "%s enter the database name." : "%s внеси го името на базата.",
    "%s you may not use dots in the database name" : "%s не можеш да користиш точки во името на базата",
    "Oracle username and/or password not valid" : "Oracle корисничкото име и/или лозинката не се валидни",
    "DB Error: \"%s\"" : "DB грешка: \"%s\"",
    "Offending command was: \"%s\"" : "Навредувшката команда беше: \"%s\"",
    "PostgreSQL username and/or password not valid" : "PostgreSQL корисничкото име и/или лозинка не се валидни",
    "Set an admin username." : "Постави администраторско корисничко име",
    "Set an admin password." : "Постави администраторска лозинка.",
    "%s shared »%s« with you" : "%s споделено »%s« со вас",
    "Could not find category \"%s\"" : "Не можам да најдам категорија „%s“",
    "Apps" : "Аппликации",
    "A valid username must be provided" : "Мора да се обезбеди валидно корисничко име ",
    "A valid password must be provided" : "Мора да се обезбеди валидна лозинка",
    "The username is already being used" : "Корисничкото име е веќе во употреба",
    "Storage not available" : "Сториџот не е достапен"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
